#!/usr/bin/env python
from distutils.core import setup

setup(
    name='A3MIO',
    version='0.0.1',
    description='A3M/A2M I/O for BioPython',
    author='Stefan Seemayer',
    author_email='mail@semicolonsoftware.de',
    url='https://github.com/sseemayer/BioPython-A3MIO',
    py_modules=['A3MIO'],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
        "Topic :: Scientific/Engineering :: Bio-Informatics"
    ]
)
